Package: apca
Type: Package
Title: Advanced Principal Component Analysis
Version: 1.0.0
Date: 2026-04-19
Authors@R: c(
    person(given = "Angga Dwi", family = "Mulyanto", role = c("aut", "cre"), email = "angga.dwi.m@gmail.com", comment = "Institut Teknologi Sepuluh Nopember, Universitas Islam Negeri Maulana Malik Ibrahim Malang"),
    person(given = "Bambang Widjanarko", family = "Otok", role = "aut", comment = "Institut Teknologi Sepuluh Nopember"),
    person(given = "Jerry Dwi Trijoyo", family = "Purnomo", role = "aut", comment = "Institut Teknologi Sepuluh Nopember")
  )
Description: Provides nine computational algorithms for dimensionality
    reduction via Principal Component Analysis (PCA), built using an
    object-oriented (S3) architecture. The package includes classical and
    modern methods: Singular Value Decomposition (SVD) based on Eckart and
    Young (1936) <doi:10.1007/BF02288367>, Power Iteration based on Hotelling
    (1933) <doi:10.1037/h0071325>, QR Algorithm based on Francis (1961)
    <doi:10.1093/comjnl/4.3.265>, Jacobi Algorithm based on Jacobi (1846)
    <doi:10.1515/crll.1846.30.51>, Arnoldi Iteration based on Arnoldi (1951)
    <doi:10.1090/qam/42792>, 'NIPALS' based on Wold (1975) <doi:10.1017/S0021900200047604>,
    Alternating Least Squares (ALS) based on Kolda and Bader (2009)
    <doi:10.1137/07070111X>, Probabilistic PCA (PPCA) with EM Algorithm based
    on Tipping and Bishop (1999) <doi:10.1111/1467-9868.00196>, and
    Generalized Hebbian Algorithm (GHA) based on Sanger (1989)
    <doi:10.1016/0893-6080(89)90044-0>.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
Imports: stats
NeedsCompilation: no
Packaged: 2026-04-24 12:56:22 UTC; A0812
Author: Angga Dwi Mulyanto [aut, cre] (Institut Teknologi Sepuluh Nopember,
    Universitas Islam Negeri Maulana Malik Ibrahim Malang),
  Bambang Widjanarko Otok [aut] (Institut Teknologi Sepuluh Nopember),
  Jerry Dwi Trijoyo Purnomo [aut] (Institut Teknologi Sepuluh Nopember)
Maintainer: Angga Dwi Mulyanto <angga.dwi.m@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-28 18:40:24 UTC
Built: R 4.5.2; ; 2026-04-28 20:07:50 UTC; unix
