% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/apca.R
\name{summary.apca}
\alias{summary.apca}
\title{Summary Method for APCA Objects}
\usage{
\method{summary}{apca}(object, ...)
}
\arguments{
\item{object}{An object of class "apca".}

\item{...}{Additional arguments affecting the summary produced.}
}
\value{
A list of class "summary.apca" containing variance explained,
cumulative variance, and other specific algorithm metrics (like noise variance).
}
\description{
Extracts and calculates cumulative variance metrics from an APCA object.
}
\examples{
data(mtcars)
res <- apca(mtcars, n_components = 3, method = "svd", scale = TRUE)

# Display cumulative variance summary
summary(res)
}
